@@ -5,7 +5,7 @@ def plugin_settings(settings):
     """
     Populate settings
     """
-    settings.TRACKING_BACKENDS['rapid_response'] = {
+    settings.EVENT_TRACKING_BACKENDS['rapid_response'] = {
         'ENGINE': 'rapid_response_xblock.logger.SubmissionRecorder',
         'OPTIONS': {
             'name': 'rapid_response',
