@@ -7,28 +7,28 @@ from mock import Mock, patch, PropertyMock
 from dateutil.parser import parse as parse_datetime
 import pytz
 from opaque_keys.edx.keys import UsageKey
-from student.tests.factories import UserFactory
 
-from rapid_response_xblock.block import (
-    RapidResponseAside,
-    BLOCK_PROBLEM_CATEGORY,
-    MULTIPLE_CHOICE_TYPE,
+from tests.utils import (
+    make_scope_ids,
+    RuntimeEnabledTestCase,
 )
 from rapid_response_xblock.models import (
     RapidResponseRun,
     RapidResponseSubmission,
 )
-from tests.utils import (
-    make_scope_ids,
-    RuntimeEnabledTestCase,
+from rapid_response_xblock.block import (
+    RapidResponseAside,
+    BLOCK_PROBLEM_CATEGORY,
+    MULTIPLE_CHOICE_TYPE,
 )
+from common.djangoapps.student.tests.factories import UserFactory
 
 
 @ddt
 class RapidResponseAsideTests(RuntimeEnabledTestCase):
     """Tests for RapidResponseAside logic"""
     def setUp(self):
-        super(RapidResponseAsideTests, self).setUp()
+        super().setUp()
         self.aside_usage_key = UsageKey.from_string(
             "aside-usage-v2:block-v1$:SGAU+SGA101+2017_SGA+type@problem+block"
             "@2582bbb68672426297e525b49a383eb8::rapid_response_xblock"
